package net.minecraft.src.forestry.api;

import net.minecraft.src.ItemStack;

/**
 * Provides an interface to the recipe manager of the carpenter.
 * Only shaped recipes can be added currently.
 * @author SirSengir
 */
public interface ICarpenterManager {
	/**
	 * Add a shaped recipe to the carpenter.
	 * @param box ItemStack of one item representing the required box (carton, crate) for this recipe. May be null.
	 * @param product Crafting result.
	 * @param materials Materials needed in the crafting matrix. This gets passed directly to {@link ShapedRecipes}. Notation is the same.
	 */
	public void addRecipe(ItemStack box, ItemStack product, Object materials[]);
	/**
	 * Add a shaped recipe to the carpenter.
	 * @param packagingTime Number of work cycles required to craft the recipe once.
	 * @param box ItemStack of one item representing the required box (carton, crate) for this recipe. May be null.
	 * @param product Crafting result.
	 * @param materials Materials needed in the crafting matrix. This gets passed directly to {@link ShapedRecipes}. Notation is the same.
	 */
	public void addRecipe(int packagingTime, ItemStack box, ItemStack product, Object materials[]);
	/**
	 * Add a shaped recipe to the carpenter.
	 * @param packagingTime Number of work cycles required to craft the recipe once.
	 * @param liquidId Id of liquid required in tank. Everything other than Block.waterStill.blockId is untested!
	 * @param liquidAmount Amount of liquid required to craft the recipe once. One bucket of water = one unit on the carpenter's tank = 1000.
	 * @param box ItemStack of one item representing the required box (carton, crate) for this recipe. May be null.
	 * @param product Crafting result.
	 * @param materials Materials needed in the crafting matrix. This gets passed directly to {@link ShapedRecipes}. Notation is the same.
	 */
	public void addRecipe(int packagingTime, int liquidId, int liquidAmount, ItemStack box, ItemStack product, Object materials[]);
}
